# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import click

from clapper.click import verbosity_option
from clapper.logging import setup

logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")


@click.command(
    epilog="""Examples:

\b
    1. Takes all the .csv files resulting from the visualize command and generates
         a summary.csv file containing a summary of the results.

       .. code:: sh

          ptbench evaluatevis -i path/to/input_folder
""",
)
@click.option(
    "--input-folder",
    "-i",
    help="Path to the folder including the .csv files with the individual scores.",
    required=True,
    type=click.Path(),
)
@verbosity_option(logger=logger, expose_value=False)
def evaluatevis(input_folder) -> None:
    """Calculates summary statistics for the scores for one visualization
    type."""

    from ..utils.cam_utils import calculate_metrics_avg_for_every_class

    calculate_metrics_avg_for_every_class(input_folder)
